package com.ym.mec.student.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.dayaedu.cbs.openfeign.client.CoursewareFeignService;
import com.dayaedu.cbs.openfeign.wrapper.courseware.CbsLessonCoursewareDetailWrapper;
import com.dayaedu.cbs.openfeign.wrapper.courseware.CbsLessonCoursewareWrapper;
import com.microsvc.toolkit.common.response.paging.QueryInfo;
import com.ym.mec.biz.dal.entity.Subject;
import com.ym.mec.biz.dal.wrapper.LessonCoursewareWrapper;
import com.ym.mec.biz.service.LessonCoursewareService;
import com.ym.mec.common.controller.BaseController;
import com.ym.mec.common.entity.HttpResponseResult;
import com.ym.mec.common.page.PageInfo;
import com.ym.mec.common.page.PageUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

@RequestMapping("${app-config.url.student:}/lessonCourseware")
@Api(tags = "课件教材")
@RestController
public class LessonCoursewareController extends BaseController {

	@Autowired
	private CoursewareFeignService coursewareFeignService;
	@Resource
	private LessonCoursewareService lessonCoursewareService;

	@ApiOperation(value = "分页查询已添加的课件")
	@PostMapping("/queryLessonCourseware")
	public HttpResponseResult<PageInfo<LessonCoursewareWrapper.LessonCoursewareDto>> queryLessonCourseware(@RequestBody LessonCoursewareWrapper.LessonCoursewareQuery query){
		query.setEnable(true);
		IPage<LessonCoursewareWrapper.LessonCoursewareDto> pages = lessonCoursewareService.selectPage(QueryInfo.getPage(query), query);
		return succeed(PageUtil.pageInfo(pages));
	}

	@ApiOperation(value = "获取课件详情")
	@GetMapping("/getLessonCoursewareDetail/{id}")
	public HttpResponseResult<CbsLessonCoursewareWrapper.LessonCourseware> getLessonCoursewareDetail(@PathVariable("id") Long id){
		return succeed(coursewareFeignService.lessonCoursewareDetail(id).feignData());
	}

	@ApiOperation(value = "获取课件关联的课程列表")
	@GetMapping("/getLessonCoursewareCourseList/{id}")
	public HttpResponseResult<List<LessonCoursewareWrapper.CourseScheduleCoursewareDetail>> getLessonCoursewareCourseList(@PathVariable("id") Long id){
		List<CbsLessonCoursewareWrapper.CourseScheduleCoursewareDetail> courseScheduleCoursewareDetails = coursewareFeignService.coursewareDetail(id).feignData();
		if (CollectionUtils.isNotEmpty(courseScheduleCoursewareDetails)) {
			String jsonString = JSONObject.toJSONString(courseScheduleCoursewareDetails);
			List<LessonCoursewareWrapper.CourseScheduleCoursewareDetail> courseScheduleCoursewareDetailList = JSONObject.parseArray(jsonString, LessonCoursewareWrapper.CourseScheduleCoursewareDetail.class);
			return succeed(courseScheduleCoursewareDetailList);
		}
		return succeed(new ArrayList<>());
	}

	@ApiOperation(value = "获取课程详情")
	@GetMapping("/getLessonCourseDetail/{id}")
	public HttpResponseResult<CbsLessonCoursewareDetailWrapper.LessonCoursewareDetail> getLessonCourseDetail(@PathVariable("id") String id){
		return succeed(coursewareFeignService.lessonCoursewareDetailDetail(Long.parseLong(id)).feignData());
	}

	@ApiOperation(value = "获取课件关联的声部列表")
	@GetMapping("/getLessonCoursewareSubjectList")
	public HttpResponseResult<List<Subject>> getLessonCoursewareSubjectList(){
		return succeed(lessonCoursewareService.getDao().getLessonCoursewareSubjectList());
	}
}
