package com.ym.mec.biz.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.dayaedu.cbs.openfeign.client.CoursewareFeignService;
import com.dayaedu.cbs.openfeign.wrapper.courseware.CbsLessonCoursewareWrapper;
import com.ym.mec.biz.dal.dao.SubjectDao;
import com.ym.mec.biz.dal.mapper.LessonCoursewareMapper;
import com.ym.mec.biz.dal.entity.LessonCourseware;
import com.ym.mec.biz.dal.wrapper.LessonCoursewareWrapper;
import com.ym.mec.biz.service.LessonCoursewareService;
import com.ym.mec.biz.service.SubjectService;
import com.ym.mec.util.collection.MapUtil;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;

@Service
public class LessonCoursewareServiceImpl extends ServiceImpl<LessonCoursewareMapper, LessonCourseware> implements LessonCoursewareService {

    private final static Logger log = LoggerFactory.getLogger(LessonCoursewareServiceImpl.class);


    @Override
    public LessonCoursewareMapper getDao() {
        return this.baseMapper;
    }

    @Autowired
    private CoursewareFeignService coursewareFeignService;
    @Resource
    private SubjectDao subjectDao;

    @Override
    public IPage<LessonCoursewareWrapper.LessonCoursewareDto> selectPage(IPage<LessonCoursewareWrapper.LessonCoursewareDto> page, LessonCoursewareWrapper.LessonCoursewareQuery query) {
        List<LessonCoursewareWrapper.LessonCoursewareDto> dtos = baseMapper.selectPage(page, query);
        if(CollectionUtils.isNotEmpty(dtos)){
            List<Long> lessonCoursewareIds = dtos.stream().map(LessonCoursewareWrapper.LessonCoursewareDto::getLessonCoursewareId).collect(Collectors.toList());
            CbsLessonCoursewareWrapper.LambdaQuery lambdaQuery = new CbsLessonCoursewareWrapper.LambdaQuery();
            lambdaQuery.setIds(lessonCoursewareIds);
            List<CbsLessonCoursewareWrapper.Entity> entityList = coursewareFeignService.lessonCoursewareLambdaQuery(lambdaQuery).feignData();
            if(CollectionUtils.isNotEmpty(entityList)){
                Map<Long, CbsLessonCoursewareWrapper.Entity> entityMap = entityList.stream().collect(Collectors.groupingBy(CbsLessonCoursewareWrapper.Entity::getId,
                        Collectors.collectingAndThen(Collectors.toList(), e -> e.get(0))));
                for (LessonCoursewareWrapper.LessonCoursewareDto e : dtos) {
                    CbsLessonCoursewareWrapper.Entity entity = entityMap.get(e.getLessonCoursewareId());
                    if (Objects.isNull(entity)) {
                        continue;
                    }
                    e.setName(entity.getName());
                    e.setCover(entity.getCoverImg());
                    e.setCourseNum(entity.getCourseNum());
                }
            }
            List<Integer> collect = dtos.stream().map(e -> e.getSubjectId()).collect(Collectors.toList());
            if(CollectionUtils.isNotEmpty(collect)){
                String subjectIds = collect.stream().map(e -> String.valueOf(e)).collect(Collectors.joining(","));
                List<Map<Integer, String>> subjectNames = subjectDao.queryNameByIds(subjectIds);
                Map<Integer, String> subjectNameMap = MapUtil.convertMybatisMap(subjectNames);
                for (LessonCoursewareWrapper.LessonCoursewareDto e : dtos) {
                    e.setSubjectName(subjectNameMap.get(e.getSubjectId()));
                }
            }
        }
        return page.setRecords(dtos);
    }

}

